@@ -29,7 +29,8 @@ def doReset():
     wf_job = group(addWFS.si(x) for x in chunk_dict(wfs,10000))
     spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
     trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
-    res = (loadCats.si() |spell_job )()
+    c2 = (loadCats.si() | lemma_job | wf_job |spell_job | trans_job | addRelationships.si(wfs))
+    res = c2()
     res.get()
 
 
@@ -75,7 +76,7 @@ def addRelationships(wfs):
     for w in wfs:
         ss = list(Orthography.objects.filter(Spelling__in = wfs[str(w.pk)]['Spellings']))
         w.Orthographies.add(*ss)
-        ss = list(Transcription.objects.filter(Transcription__in = wfs[str(w.pk)]['Transcriptions']))
+        ts = list(Transcription.objects.filter(Transcription__in = wfs[str(w.pk)]['Transcriptions']))
         w.Transcriptions.add(*ts)
 
 @task()
@@ -90,11 +91,13 @@ def addWFS(wfs):
 
 @task()
 def addSpells(spells):
-    Orthography.objects.bulk_create([Orthography(pk=s[0],Spelling = s[1]) for s in spells])
+    ss = [Orthography(pk=s[0],Spelling = s[1]) for s in spells]
+    Orthography.objects.bulk_create(ss)
 
 @task()
-def addTrans(spells):
-    Transcription.objects.bulk_create([Transcription(pk=t[0],Transcription = t[1]) for t in trans])
+def addTrans(trans):
+    ts = Transcription(pk=t[0],Transcription = t[1]) for t in trans]
+    Transcription.objects.bulk_create(ts)
 
 
 def loadOrthLemmas():
@@ -170,19 +173,19 @@ def loadTransWF(wfs):
             ts.extend(trans)
     return wfs,ts
 
-def loadTransLemmas(lemmas):
-    with open(fetch_celex_resource('Phonology/celex-phonology-lemmas.txt'),'r') as f:
-        head = None
-        for line in f:
-            l = line.strip().split("\\")
-            if head is None:
-                head = l
-                continue
-            main = l[:8]
-            additional = l[8:]
-            trans = [main[5]]
-            if len(additional) != 0:
-                additional = chunks(additional,4)
-                trans.extend([x[1] for x in additional])
-            lemmas[l[0]]['Transcriptions'] = set(trans)
-    return lemmas
+#def loadTransLemmas(lemmas):
+#    with open(fetch_celex_resource('Phonology/celex-phonology-lemmas.txt'),'r') as f:
+#        head = None
+#        for line in f:
+#            l = line.strip().split("\\")
+#            if head is None:
+#                head = l
+#                continue
+#            main = l[:8]
+#            additional = l[8:]
+#            trans = [main[5]]
+#            if len(additional) != 0:
+#                additional = chunks(additional,4)
+#                trans.extend([x[1] for x in additional])
+#            lemmas[l[0]]['Transcriptions'] = set(trans)
+#    return lemmas
